# cs107-FinalProject
Final project repository for CS107 Group 17

Team members:
* William Hoback
* Gerald Arocena
* Xiaoxuan Liu
* M. Elaine Cunha

[![Build Status](https://travis-ci.com/teamxvii/cs107-FinalProject.svg?branch=master)](https://travis-ci.com/teamxvii/cs107-FinalProject)
[![codecov](https://codecov.io/gh/teamxvii/cs107-FinalProject/branch/master/graph/badge.svg?token=VVBQSYY46I)](https://codecov.io/gh/teamxvii/cs107-FinalProject)
